pub(crate) async fn send_login_request(
identity_config: &Configuration,
api_request: &LoginApiRequest<impl Serialize + DeserializeOwned + Debug>,
) -> Result<LoginResponse, LoginErrorApiResponse>Expand description
A common function to send login requests to the Identity connect/token endpoint. Returns a common success model which has already been converted from the API response, or a common error model representing the login error which allows for conversion to specific error types based on the login method used.